Class: Operaton::Bpm::Client::Impl::EngineClientLogger
Overview
Mirrors org.operaton.bpm.client.impl.EngineClientLogger
Constant Summary
Operaton::Bpm::Client::Impl::ExternalTaskClientLogger::PROJECT_CODE
Instance Method Summary
collapse
#async_response_timeout_not_greater_than_zero_exception, #base_url_null_exception, #basic_auth_credentials_null_exception, #cannot_get_hostname_exception, #cannot_serialize_variable, client_logger, #create_message, #double_direction_config_exception, engine_client_logger, #exception_message, #external_task_handler_null_exception, #format_template, #handled_engine_client_exception, #initialize, #interceptor_null_exception, #lock_duration_is_not_greater_than_zero_exception, #log_data_format, #log_data_format_configurator, #log_data_format_provider, #log_debug, #log_error, #log_info, #max_tasks_not_greater_than_zero_exception, #missing_direction_exception, #multiple_providers_for_dataformat, #pass_null_value_parameter, #topic_name_already_subscribed_exception, #topic_name_null_exception, topic_subscription_manager_logger, #unspecified_order_by_method_exception, #value_mapper_exception_due_to_no_object_type_name, #value_mapper_exception_due_to_serializer_not_found_for_typed_value, #value_mapper_exception_due_to_serializer_not_found_for_typed_value_field, #value_mapper_exception_while_deserializing_object, #value_mapper_exception_while_parsing_date, #value_mapper_exception_while_serializing_abstract_value, #value_mapper_exception_while_serializing_object
Instance Method Details
#exception_while_closing_resource_stream(response, error) ⇒ Object
23
24
25
|
# File 'lib/operaton/bpm/client/impl/engine_client_logger.rb', line 23
def exception_while_closing_resource_stream(response, error)
log_error("003", "Exception while closing resource stream of response '{}': ", error, response)
end
|
#exception_while_deserializing_json_object(response_dto_class, error) ⇒ Object
37
38
39
40
|
# File 'lib/operaton/bpm/client/impl/engine_client_logger.rb', line 37
def exception_while_deserializing_json_object(response_dto_class, error)
EngineClientException.new(exception_message(
"006", "Exception while deserializing json object to response dto class '{}'", response_dto_class), error)
end
|
#exception_while_establishing_connection(http_request, error) ⇒ Object
18
19
20
21
|
# File 'lib/operaton/bpm/client/impl/engine_client_logger.rb', line 18
def exception_while_establishing_connection(http_request, error)
EngineClientException.new(exception_message(
"002", "Exception while establishing connection for request '{}'", http_request), error)
end
|
#exception_while_mapping_json_object(response_dto_class, error) ⇒ Object
32
33
34
35
|
# File 'lib/operaton/bpm/client/impl/engine_client_logger.rb', line 32
def exception_while_mapping_json_object(response_dto_class, error)
EngineClientException.new(exception_message(
"005", "Exception while mapping json object to response dto class '{}'", response_dto_class), error)
end
|
#exception_while_parsing_json_object(response_dto_class, error) ⇒ Object
27
28
29
30
|
# File 'lib/operaton/bpm/client/impl/engine_client_logger.rb', line 27
def exception_while_parsing_json_object(response_dto_class, error)
EngineClientException.new(exception_message(
"004", "Exception while parsing json object to response dto class '{}'", response_dto_class), error)
end
|
#exception_while_receiving_response(http_request, error) ⇒ Object
12
13
14
15
16
|
# File 'lib/operaton/bpm/client/impl/engine_client_logger.rb', line 12
def exception_while_receiving_response(http_request, error)
EngineClientException.new(exception_message(
"001", "Request '{}' returned error: status code '{}' - message: {}",
http_request, error.http_status_code, error.message), error)
end
|
#exception_while_serializing_json_object(dto, error) ⇒ Object
42
43
44
45
|
# File 'lib/operaton/bpm/client/impl/engine_client_logger.rb', line 42
def exception_while_serializing_json_object(dto, error)
EngineClientException.new(exception_message(
"007", "Exception while serializing json object to '{}'", dto), error)
end
|
#request_interceptor_exception(error) ⇒ Object
47
48
49
|
# File 'lib/operaton/bpm/client/impl/engine_client_logger.rb', line 47
def request_interceptor_exception(error)
log_error("008", "Exception while executing request interceptor: {}", error)
end
|