Class: Operaton::Bpm::Client::Topic::Impl::TopicSubscriptionImpl
- Inherits:
-
Object
- Object
- Operaton::Bpm::Client::Topic::Impl::TopicSubscriptionImpl
- Includes:
- TopicSubscription
- Defined in:
- lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb
Overview
Mirrors org.operaton.bpm.client.topic.impl.TopicSubscriptionImpl
Constant Summary
Constants included from TopicSubscription
TopicSubscription::INTERFACE_METHODS
Instance Attribute Summary collapse
-
#business_key ⇒ Object
readonly
Returns the value of attribute business_key.
-
#external_task_handler ⇒ Object
readonly
Returns the value of attribute external_task_handler.
-
#include_extension_properties ⇒ Object
writeonly
Sets the attribute include_extension_properties.
-
#local_variables ⇒ Object
writeonly
Sets the attribute local_variables.
-
#lock_duration ⇒ Object
readonly
Returns the value of attribute lock_duration.
-
#process_definition_id ⇒ Object
Returns the value of attribute process_definition_id.
-
#process_definition_id_in ⇒ Object
Returns the value of attribute process_definition_id_in.
-
#process_definition_key ⇒ Object
Returns the value of attribute process_definition_key.
-
#process_definition_key_in ⇒ Object
Returns the value of attribute process_definition_key_in.
-
#process_definition_version_tag ⇒ Object
Returns the value of attribute process_definition_version_tag.
-
#process_variables ⇒ Object
Returns the value of attribute process_variables.
-
#tenant_id_in ⇒ Object
Returns the value of attribute tenant_id_in.
-
#topic_name ⇒ Object
readonly
Returns the value of attribute topic_name.
-
#variable_names ⇒ Object
readonly
Returns the value of attribute variable_names.
-
#without_tenant_id ⇒ Object
writeonly
Sets the attribute without_tenant_id.
Instance Method Summary collapse
-
#==(other) ⇒ Object
(also: #eql?)
Java equality is based on class and topic name only.
- #close ⇒ Object
- #hash ⇒ Object
- #include_extension_properties? ⇒ Boolean
-
#initialize(topic_name, lock_duration, external_task_handler, topic_subscription_manager, variable_names, business_key) ⇒ TopicSubscriptionImpl
constructor
A new instance of TopicSubscriptionImpl.
- #local_variables? ⇒ Boolean
- #without_tenant_id? ⇒ Boolean
Constructor Details
#initialize(topic_name, lock_duration, external_task_handler, topic_subscription_manager, variable_names, business_key) ⇒ TopicSubscriptionImpl
Returns a new instance of TopicSubscriptionImpl.
19 20 21 22 23 24 25 26 27 28 29 30 31 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 19 def initialize(topic_name, lock_duration, external_task_handler, topic_subscription_manager, variable_names, business_key) @topic_name = topic_name @lock_duration = lock_duration @external_task_handler = external_task_handler @topic_subscription_manager = topic_subscription_manager @variable_names = variable_names @business_key = business_key @local_variables = false @without_tenant_id = false @include_extension_properties = false @process_variables = nil end |
Instance Attribute Details
#business_key ⇒ Object (readonly)
Returns the value of attribute business_key.
14 15 16 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 14 def business_key @business_key end |
#external_task_handler ⇒ Object (readonly)
Returns the value of attribute external_task_handler.
14 15 16 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 14 def external_task_handler @external_task_handler end |
#include_extension_properties=(value) ⇒ Object (writeonly)
Sets the attribute include_extension_properties
60 61 62 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 60 def include_extension_properties=(value) @include_extension_properties = value end |
#local_variables=(value) ⇒ Object (writeonly)
Sets the attribute local_variables
41 42 43 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 41 def local_variables=(value) @local_variables = value end |
#lock_duration ⇒ Object (readonly)
Returns the value of attribute lock_duration.
14 15 16 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 14 def lock_duration @lock_duration end |
#process_definition_id ⇒ Object
Returns the value of attribute process_definition_id.
15 16 17 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 15 def process_definition_id @process_definition_id end |
#process_definition_id_in ⇒ Object
Returns the value of attribute process_definition_id_in.
15 16 17 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 15 def process_definition_id_in @process_definition_id_in end |
#process_definition_key ⇒ Object
Returns the value of attribute process_definition_key.
15 16 17 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 15 def process_definition_key @process_definition_key end |
#process_definition_key_in ⇒ Object
Returns the value of attribute process_definition_key_in.
15 16 17 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 15 def process_definition_key_in @process_definition_key_in end |
#process_definition_version_tag ⇒ Object
Returns the value of attribute process_definition_version_tag.
15 16 17 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 15 def process_definition_version_tag @process_definition_version_tag end |
#process_variables ⇒ Object
Returns the value of attribute process_variables.
43 44 45 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 43 def process_variables @process_variables end |
#tenant_id_in ⇒ Object
Returns the value of attribute tenant_id_in.
15 16 17 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 15 def tenant_id_in @tenant_id_in end |
#topic_name ⇒ Object (readonly)
Returns the value of attribute topic_name.
14 15 16 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 14 def topic_name @topic_name end |
#variable_names ⇒ Object (readonly)
Returns the value of attribute variable_names.
14 15 16 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 14 def variable_names @variable_names end |
#without_tenant_id=(value) ⇒ Object (writeonly)
Sets the attribute without_tenant_id
54 55 56 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 54 def without_tenant_id=(value) @without_tenant_id = value end |
Instance Method Details
#==(other) ⇒ Object Also known as: eql?
Java equality is based on class and topic name only.
63 64 65 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 63 def ==(other) other.instance_of?(self.class) && topic_name == other.topic_name end |
#close ⇒ Object
33 34 35 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 33 def close @topic_subscription_manager.unsubscribe(self) end |
#hash ⇒ Object
68 69 70 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 68 def hash [self.class, topic_name].hash end |
#include_extension_properties? ⇒ Boolean
56 57 58 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 56 def include_extension_properties? @include_extension_properties end |
#local_variables? ⇒ Boolean
37 38 39 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 37 def local_variables? @local_variables end |
#without_tenant_id? ⇒ Boolean
50 51 52 |
# File 'lib/operaton/bpm/client/topic/impl/topic_subscription_impl.rb', line 50 def without_tenant_id? @without_tenant_id end |